@@ -10,7 +10,7 @@ import logging
 import argparse
 import sys
 from collections import OrderedDict
-from tempfile import NamedTemporaryFile
+from io import StringIO
 from pathlib import Path
 import propka.lib
 import propka.output as pk_out
@@ -461,7 +461,7 @@ def is_repairable(biomolecule, has_ligand):
     miss_frac = float(num_missing) / float(num_heavy)
     if miss_frac > REPAIR_LIMIT:
         error = f"This PDB file is missing too many ({num_missing} out of "
-        error += f"{num_heavy:i}, {miss_frac:g}) "
+        error += f"{num_heavy:d}, {miss_frac:g}) "
         error += "heavy atoms to accurately repair the file."
         error += f"The current repair limit is set at {REPAIR_LIMIT:g}. "
         error += "You may also see this message if PDB2PQR does not have "
@@ -505,18 +505,19 @@ def run_propka(args, biomolecule):
                pKa information from PROPKA)
     :rtype:  (list, str)
     """
-    # TODO - eliminate need to write temporary file
+
     lines = io.print_biomolecule_atoms(
         atomlist=biomolecule.atoms, chainflag=args.keep_chain, pdbfile=True
     )
-    with NamedTemporaryFile("wt", suffix=".pdb") as pdb_file:
-        for line in lines:
-            pdb_file.write(line)
-        pdb_path = pdb_file.name
 
+    with StringIO() as fpdb:
+        fpdb.writelines(lines)
         parameters = pk_in.read_parameter_file(args.parameters, Parameters())
         molecule = MolecularContainer(parameters, args)
-        molecule = pk_in.read_molecule_file(pdb_path, molecule)
+        # needs a mock name with .pdb extension to work with stream data, hence the "input.pdb"
+        molecule = pk_in.read_molecule_file("input.pdb", molecule, fpdb)
+
+
 
     molecule.calculate_pka()
 
@@ -636,7 +637,13 @@ def non_trivial(args, biomolecule, ligand, definition, is_cif):
             biomolecule.apply_pka_values(
                 forcefield_.name,
                 args.ph,
-                {f"{row['res_name']} {row['res_num']} {row['chain_id']}": row["pKa"] for row in pka_df if row["group_label"].startswith(row["res_name"])},
+                {
+                    f"{row['res_name']} {row['res_num']} {row['chain_id']}": row[
+                        "pKa"
+                    ]
+                    for row in pka_df
+                    if row["group_label"].startswith(row["res_name"])
+                },
             )
 
         _LOGGER.info("Adding hydrogens to biomolecule.")
