@@ -20,3 +20,14 @@ def test_propka_apo(input_pdb, tmp_path):
         output_pqr=output_pqr,
         tmp_path=tmp_path,
     )
+
+
+@pytest.mark.parametrize(
+    "input_pdb", ["1K1I", "1AFS", "1FAS", "5DV8", "5D8V"], ids=str
+)
+def test_propka_pka(input_pdb):
+    """PROPKA non-regression tests for pKa values on biomolecules without ligands."""
+    output_csv = Path("tests/data") / f"{input_pdb}_pka.csv"
+    common.run_propka_for_tests(
+        input_pdb=input_pdb, compare_file=output_csv, pH=7.4
+    )
